<?php
/**
 *  Oviyan functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Oviyan
 * @since 1.0
 */

// Defining Some Variable
if( !defined( 'OVIYAN_LITE_VERSION' ) ) {
	define('OVIYAN_LITE_VERSION', '1.0.3'); // Theme Version
}
if( !defined( 'OVIYAN_LITE_DIR' ) ) {
	define( 'OVIYAN_LITE_DIR', get_template_directory() ); // Theme dir
}
if( !defined( 'OVIYAN_LITE_URL' ) ) {
	define( 'OVIYAN_LITE_URL', get_template_directory_uri() ); // Theme url
}


// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 1170;
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function oviyan_lite_setup() {
	
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Oviyan, use a find and replace
	 * to change 'oviyan-lite' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'oviyan-lite', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
        
        // This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();
        
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );	
	add_image_size( 'oviyan-lite-soft-featured', 870, 999999, false );
	set_post_thumbnail_size( 870, 500, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'top-menu' 		=> esc_html__( 'Top Menu', 'oviyan-lite' ),	
		'main-menu' 	=> esc_html__( 'Main Menu', 'oviyan-lite' ),
		'footer-menu' 	=> esc_html__( 'Footer Menu', 'oviyan-lite' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'oviyan_lite_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Add support for custom logo.
	add_theme_support( 'custom-logo' );

	// Post format.
	add_theme_support( 'post-formats', array('video', 'audio', 'quote', 'gallery'));

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );	
}
add_action( 'after_setup_theme', 'oviyan_lite_setup' );

/**
 * Admin Welcome Notice
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_admin_welcom_notice() {
	global $pagenow;

	if ( is_admin() && isset( $_GET['activated'] ) && 'themes.php' === $pagenow ) {
		echo '<div class="updated notice notice-success is-dismissible"><p>'.sprintf( __( 'Thank you for choosing Oviyan Lite Blog Theme. To get started, visit our <a href="%s">welcome page</a>.', 'oviyan-lite' ), esc_url( admin_url( 'themes.php?page=oviyan-lite' ) ) ).'</p></div>';
	}
}
add_action( 'admin_notices', 'oviyan_lite_admin_welcom_notice' );

/**
 * Handles Post Classes
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_render_post_classes( $classes ) {
	
	$wrapper = has_post_thumbnail();	
       
	if ( $wrapper ) {
		$classes[] = 'oviyan-lite-has-thumbnail';
	}

	// Add class according to blog layout
    if( is_home() ) { // Blog Page

        $blog_layout	    = oviyan_lite_get_theme_mod( 'blog_layout' );
		$blog_layout_grid 	= oviyan_lite_get_theme_mod( 'blog_layout_grid' );

		$classes[] = "oviyan-lite-{$blog_layout}";
		$classes[] = ( $blog_layout == 'grid' || $blog_layout == 'masonry' ) ? 'oviyan-lite-columns oviyan-lite-col-'.$blog_layout_grid : 'oviyan-lite-columns oviyan-lite-col-12';
                
                
                if ( $blog_layout == 'grid' || $blog_layout == 'masonry' ) {
                    $classes[] = "oviyan-lite-post-grid";            
                } else if ($blog_layout == 'list') {
                    
                    $classes[]="oviyan-lite-post-list";
                    
                } else if ($blog_layout == 'list-alt') {
                    $classes[]="oviyan-lite-post-list-alt";
                }
		

	} else if( is_search() || is_author() ) { // Category Page
            
		$classes[] = "oviyan-lite-list";
                $classes[] = 'oviyan-lite-columns oviyan-lite-col-12';
                $classes[] = "oviyan-lite-post-list";
                
	} else if( (is_category() || is_archive() || is_tag()) && ( (class_exists('WooCommerce') && !is_post_type_archive('product')) || !class_exists('WooCommerce') ) ) { // Category Page
                
		$cat_layout 		= oviyan_lite_get_theme_mod( 'cat_layout' );
		$cat_layout_grid 	= oviyan_lite_get_theme_mod( 'cat_layout_grid' );

		$classes[] = "oviyan-lite-{$cat_layout}";		
                
                $classes[] = ( $cat_layout == 'grid' || $cat_layout == 'masonry' ) ? 'oviyan-lite-columns oviyan-lite-col-'.$cat_layout_grid : 'oviyan-lite-columns oviyan-lite-col-12';
                
                if ( $cat_layout == 'grid' || $cat_layout == 'masonry' ) {
                    $classes[] = "oviyan-lite-post-grid";            
                } else if ($cat_layout == 'list') {
                    
                    $classes[]="oviyan-lite-post-list";
                    
                } else if ($cat_layout == 'list-alt') {
                    $classes[]="oviyan-lite-post-list-alt";
                }               
                
	}

	return $classes;
}
add_filter( 'post_class', 'oviyan_lite_render_post_classes' );

/**
	* Register Sidebars
	* 
	* @package Amyra Lite
	* @since 1.0
	*/
	function oviyan_lite_register_sidebar() {

		// Main Sidebar Area
		register_sidebar( array(
			'name'          => __( 'Main Sidebar', 'oviyan-lite' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'Appears on posts and pages.', 'oviyan-lite' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		));
		
		

		// Footer Sidebar Area
		register_sidebar( array(
			'name'          => __( 'Footer', 'oviyan-lite' ),
			'id'            => 'footer',
			'description'   => __( 'Footer Widhet Area : Add widgets here.', 'oviyan-lite' ),
			'before_widget' => '<section id="%1$s" class="widget oviyan-lite-columns '. oviyan_lite_footer_widgets_cls( 'footer' ) .' %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		));

		// Footer Instgarm Widget Area
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Instgarm Widget Area', 'oviyan-lite' ),
			'id'            => 'oviyan-lite-intsgram-feed',
			'description'   => esc_html__( 'Add widgets here.', 'oviyan-lite' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		));
	}
	// Action to register sidebar
		
	add_action( 'widgets_init', 'oviyan_lite_register_sidebar' );
	
if ( ! function_exists( 'oviyan_lite_fonts_url' ) ) {
/**
 * Register Google fonts for Oviyan Lite.
 * Create your own oviyan_lite_fonts_url() function to override in a child theme.
 * @return string Google fonts URL for the theme.
 */
function oviyan_lite_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Poppins, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Poppins font: on or off', 'oviyan-lite' ) ) {
		$fonts[] = 'Poppins:400,500,700';
	}
	/* translators: If there are characters in your language that are not supported by Roboto, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'oviyan-lite' ) ) {
		$fonts[] = 'Roboto:400,500';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
}	
/**
/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'oviyan_lite_pingback_header', 5 );

// Common Functions File
require_once OVIYAN_LITE_DIR . '/includes/oviyan-functions.php';

// Custom template tags for this theme
require_once OVIYAN_LITE_DIR . '/includes/template-tags.php';

// Theme Customizer Settings
require_once OVIYAN_LITE_DIR . '/includes/customizer.php';

// Script Class
require_once( OVIYAN_LITE_DIR . '/includes/class-oviyan-script.php' );

// Theme Dynemic CSS
require_once( OVIYAN_LITE_DIR . '/includes/oviyan-theme-css.php' );

/**
 * Load tab dashboard
 */
if ( is_admin() || ( defined( 'WP_CLI' ) && WP_CLI ) ) {
    require get_template_directory() . '/includes/dashboard/oviyan-how-it-work.php';
    
}

/************Category image Module Module End******************/

// Plugin recomendation class
require_once( OVIYAN_LITE_DIR . '/includes/plugins/class-wpcrt-recommendation.php' );