<?php
/**
 * Script Class
 *
 * Handles the script and style functionality of plugin
 *
 * @package Oviyan
 * @since 1.0
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

class Oviyan_Script {
	
	function __construct() {

		// Action to add style in front end
		add_action( 'wp_enqueue_scripts', array($this, 'oviyan_lite_front_styles'), 1 );

		// Action to add script in front end
		add_action( 'wp_enqueue_scripts', array($this, 'oviyan_lite_front_scripts'), 1 );
    
	}
 

	/**
	 * Enqueue styles for front-end
	 * 
	 * @package Oviyan
	 * @since 1.0
	 */
	function oviyan_lite_front_styles() {
		global $wp_styles;
		

		// Font Awesome CSS
		wp_register_style( 'font-awesome', OVIYAN_LITE_URL . '/assets/css/font-awesome.min.css', array(), OVIYAN_LITE_VERSION);
		wp_enqueue_style( 'font-awesome' );	

		// custombox CSS
		wp_register_style( 'custombox', OVIYAN_LITE_URL . '/assets/css/custombox.min.css', array(), OVIYAN_LITE_VERSION);
		wp_enqueue_style( 'custombox' );	

		wp_enqueue_style( 'oviyan-lite-fonts', oviyan_lite_fonts_url(), array(), null );

		// Loads theme main stylesheet
		wp_enqueue_style( 'oviyan-lite-style', get_stylesheet_uri(), array(), OVIYAN_LITE_VERSION);

	}

	/**
	 * Enqueue scripts for front-end
	 * 
	 * @package Oviyan
	 * @since 1.0
	 */
	function oviyan_lite_front_scripts() {		
                
		/*
		 * Adds JavaScript to pages with the comment form to support
		 * sites with threaded comments (when in use).
		 */
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ){
			wp_enqueue_script( 'comment-reply' );
		}
		
		// Masonry Script
		$blog_layout 	= oviyan_lite_get_theme_mod( 'blog_layout' );
		$cat_layout		= oviyan_lite_get_theme_mod( 'cat_layout' );
		if( !empty($blog_layout) || !empty($cat_layout) ) {
			wp_enqueue_script('masonry');
		}

		// Skip Link Focus Fix Js
		wp_register_script( 'oviyan-lite-sticky-sidebar-js', OVIYAN_LITE_URL . '/assets/js/theia-sticky-sidebar.js', array('jquery'), OVIYAN_LITE_VERSION, true);
		wp_enqueue_script( 'oviyan-lite-sticky-sidebar-js' );		

		// Public Js
		wp_register_script( 'oviyan-lite-public-js', OVIYAN_LITE_URL . '/assets/js/public.js', array('jquery'), OVIYAN_LITE_VERSION, true);       
		wp_enqueue_script( 'oviyan-lite-public-js' );
                
        // Search Popup Js
        wp_register_script( 'jquery-custombox', OVIYAN_LITE_URL . '/assets/js/custombox.min.js');
		wp_enqueue_script('jquery-custombox');		        
        }
}

$oviyan_lite_script = new Oviyan_Script();