<?php
/**
 * Functions File
 *
 * @package Oviyan
 * @since 1.0
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Update theme default settings
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_default_settings() {

	$default_settings = array(		
									
                                    'menu_bar_bg_clr'                   => '#fff',
                                    'menu_bar_link_clr'                 => '#000',
                                    'menu_bar_linkh_clr'                => '#08f',
                                    'continue_read_clr'                 => '#000',
                                    'continue_read_hvr_clr'             => '#fff',
                                    'h1_clr'                       		=> '#000000',
                                    'h2_clr'                       		=> '#000000',
                                    'h3_clr'                       		=> '#000000',
                                    'h4_clr'                       		=> '#000000',
                                    'h5_clr'                       		=> '#000000',
                                    'h6_clr'                       		=> '#000000',
                                    'link_clr'                          => '#000000',
                                    'hover_link_clr'                    => '#08f',                            
                                   
                                    'show_search'                       => 1,
                                    'blog_layout'                       => 'grid',
                                    'blog_layout_grid'                  => 12,               
                                   
                                    'blog_excerpt_length'               => 40,
                                    'blog_show_date'                    => 1,
                                    'blog_show_author'                  => 1,
                                    'blog_show_cat'                     => 1,
                                    'blog_show_tags'                    => 1,
									'blog_show_comment'                 => 1,
									'blog_show_readmore'                => 1,
									'cat_layout'                        => 'grid',
                                    'cat_layout_grid'                   => 12,                                    
                                    'cat_show_date'                     => 1,
                                    'cat_show_author'                   => 1,
                                    'cat_show_cat'                      => 1,                                 
                                    'cat_show_tags'                     => 1,                                   
									'cat_show_comment'                  => 1,
									'cat_show_readmore'                 => 1,                                  
                                    'single_post_fet_img'               => 1,
                                    'related_post_show'                 => 0,
                                    'related_post_title'                => __('More from', 'oviyan-lite') ,
                                    'fc_post_layout'                    => '',
                                    'show_fc_post_home'                 => 0,
                                    'show_fc_post_front'                => 0,
                                    'show_fc_post_search'               => 0,
                                    'show_fc_post_single'               => 0,
                                    'show_fc_post_cat'                  => 0,                                                                     
                                    'header_social'                     => 0,
                                    'footer_social'                     => 0,
                                    'facebook'                          => '',
                                    'twitter'                           => '',
                                    'linkedin'                          => '',
                                    'behance'                           => '',
                                    'dribbble'                          => '',
                                    'instagram'                         => '',
                                    'youtube'                           => '',
                                    'pinterest'                         => '',
                                    'copyright'                         => __('Blog Theme', 'oviyan-lite'),
                                   
                            );

	return apply_filters('oviyan_lite_options_default_values', $default_settings );
}

/**
 * Escape Tags & Slashes
 *
 * Handles escapping the slashes and tags
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_esc_attr($data) {
    return esc_attr( $data );
}


/**
 * Function to excerpt length
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_excerpt_length( $length ) {
	$blog_excerpt_length 	= oviyan_lite_get_theme_mod( 'blog_excerpt_length' );
	if ( ! is_admin() ) {
		return $blog_excerpt_length;
	}	
}
add_filter( 'excerpt_length', 'oviyan_lite_excerpt_length', 999 );

/**
 * Function to excerpt more
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_excerpt_more( $more ) {
	if ( ! is_admin() ) {	
		return '&hellip;';
	}	
}
add_filter('excerpt_more', 'oviyan_lite_excerpt_more');

/**
 * Function to add array after specific key
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_add_array(&$array, $value, $index, $from_last = false) {
	
	if( is_array($array) && is_array($value) ) {

		if( $from_last ) {
			$total_count 	= count($array);
			$index 			= (!empty($total_count) && ($total_count > $index)) ? ($total_count-$index): $index;
		}

		$split_arr 	= array_splice($array, max(0, $index));
    	$array 		= array_merge( $array, $value, $split_arr);
	}
	return $array;
}

/**
 * Function to get footer sidebar widget class
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_footer_widgets_cls( $sidebar_id ) {	
	global $_wp_sidebars_widgets;	
	
	$sidebars_widgets_count = $_wp_sidebars_widgets;

	if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) {

		$widget_count 	= count( $sidebars_widgets_count[ $sidebar_id ] );
		$widget_classes = 'widget-count-' . count( $sidebars_widgets_count[ $sidebar_id ] );

		if ( $widget_count == 2 ) {			
			$widget_classes .= ' oviyan-lite-col-6';
		} elseif  ( $widget_count == 3 ) {			
			$widget_classes .= ' oviyan-lite-col-4';
		} elseif ( $widget_count == 4 ) {			
			$widget_classes .= ' oviyan-lite-col-3';
		}  elseif ( $widget_count == 5 ) {			
			$widget_classes .= ' oviyan-lite-col-5c';
		}  elseif ( $widget_count == 6 ) {			
			$widget_classes .= ' oviyan-lite-col-2';
		} else {			
			$widget_classes .= ' oviyan-lite-col-12';
		}
		return $widget_classes;
	}
}

/**
 * Determine where to display featured content section
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_fcs_display() {

	global $wp_query;

	$display 		= false;
	$fp_is_home 	= oviyan_lite_get_theme_mod( 'show_fc_post_home' );
	$fp_is_frontp 	= oviyan_lite_get_theme_mod( 'show_fc_post_front' );	
	$fp_is_search 	= oviyan_lite_get_theme_mod( 'show_fc_post_search' );	
	$fp_is_single 	= oviyan_lite_get_theme_mod( 'show_fc_post_single' );
	$fp_is_cat 		= oviyan_lite_get_theme_mod( 'show_fc_post_cat' );

	if( is_search() && !empty($fp_is_search) ) {
		$display = true;
	} elseif( $wp_query->is_posts_page && !empty($fp_is_home) ) {
		$display = true;
	} elseif( is_front_page() && !empty($fp_is_frontp)  ){
		$display = true;
	} elseif( !is_front_page() && is_home() && !$wp_query->is_posts_page && !empty($fp_is_home) ) { // If Front page is not set and latest post is being displayed
		$display = true;
	} elseif( get_query_var('cat') && !empty($fp_is_cat) ) { // If WordPress category page
		$display = true;
	} elseif( is_single() && !empty($fp_is_single) ) { // If WordPress single page
		$display = true;
	}

	return $display;
}



/**
 * Function to get post excerpt
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_get_post_excerpt( $post_id = null, $content = '', $word_length = '55', $more = '...' ) {

	$word_length = !empty($word_length) ? $word_length : '55';

	// If post id is passed
	if( !empty($post_id) ) {
		if (has_excerpt($post_id)) {
			$content = get_the_excerpt();
		} else {
			$content = !empty($content) ? $content : get_the_content();
		}
	}

	if( !empty($content) ) {
		$content = strip_shortcodes( $content ); // Strip shortcodes
		$content = wp_trim_words( $content, $word_length, $more );
	}

	return $content;
}

/**
 * Strip Slashes From Array
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_slashes_deep($data = array(), $flag = false) {
  
    if($flag != true) {
        $data = oviyan_lite_nohtml_kses($data);
    }
    $data = stripslashes_deep($data);
    return $data;
}


/**
 * nohtml kses
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_nohtml_kses($data = array()) {
  
  if ( is_array($data) ) {
    
    $data = array_map('oviyan_lite_nohtml_kses', $data);
    
  } elseif ( is_string( $data ) ) {
    $data = trim( $data );
    $data = wp_filter_nohtml_kses($data);
  }
  
  return $data;
}

/**
 * Function to get customizer value
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_get_theme_mod( $mod = '' ) {
	
	$default_settings 	= oviyan_lite_default_settings();
	$default_val 		= isset($default_settings[ $mod ]) ? $default_settings[ $mod ] : '';
    
        return get_theme_mod( $mod, $default_val );
}

/**
 * Clean variables using sanitize_text_field. Arrays are cleaned recursively.
 * Non-scalar values are ignored.
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_sanitize_clean( $var ) {
	if ( is_array( $var ) ) {
		return array_map( 'oviyan_lite_sanitize_clean', $var );
	} else {
		$data = is_scalar( $var ) ? sanitize_text_field( $var ) : $var;
		return wp_unslash($data);
	}
}

/**
 * Checkbox sanitization callback.
 */
function oviyan_lite_sanitize_checkbox( $checked ) {
	return ( ( !empty( $checked ) ) ? true : false );
}

/**
 * Select sanitization callback.
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_sanitize_select( $input, $setting ) {
	$input = sanitize_key( $input );
	$choices = $setting->manager->get_control( $setting->id )->choices;
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Sanitize URL
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_sanitize_url( $url ) {
	return esc_url_raw( trim($url) );
}

/**
 * Handles the footer copy right text
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_footer_copyright() {
	
	$current_year 	= date( 'Y', current_time('timestamp') );
	$copyright_text = oviyan_lite_get_theme_mod( 'copyright' );
	$copyright_text = str_replace('{year}', $current_year, $copyright_text);

	return apply_filters( 'oviyan_lite_footer_copyright', $copyright_text);

}



/**
 * Handles column if has thumb or post formate media
 *
 * @package Oviyan
 * @since 1.0
 */

function oviyan_lite_grid_column_class() {

	$grid_class =   'oviyan-lite-col-12 oviyan-lite-content-full';

	if( has_post_thumbnail()){
    	$grid_class =   'oviyan-lite-col-6 oviyan-lite-content-right';
	}	

	return $grid_class;
}



/**
 * Social icon header
 *
 * @package oviyan_lite
 * @since 1.0
 */

function oviyan_lite_get_social_icon() {

		$facebook 		= oviyan_lite_get_theme_mod( 'facebook' ); 
		$twitter 		= oviyan_lite_get_theme_mod( 'twitter' );
		$linkedin 		= oviyan_lite_get_theme_mod( 'linkedin' );
		$behance 		= oviyan_lite_get_theme_mod( 'behance' );   
		$dribbble 		= oviyan_lite_get_theme_mod( 'dribbble' );
		$instagram 		= oviyan_lite_get_theme_mod( 'instagram' );
		$youtube 		= oviyan_lite_get_theme_mod( 'youtube' );
		$pinterest  	= oviyan_lite_get_theme_mod( 'pinterest' );
		$show_search	= oviyan_lite_get_theme_mod( 'show_search' );

     	if(!empty($facebook) ) { ?>   
	            <a href="<?php echo esc_url($facebook); ?>" title="<?php esc_attr_e('Facebook','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-facebook-icon"><i class="fa fa-facebook"></i></a>
	    <?php } 
	    if(!empty($twitter) ) { ?>  
	            <a href="<?php echo esc_url($twitter); ?>" title="<?php esc_attr_e('Twitter','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-twitter-icon"><i class="fa fa-twitter"></i></a>
	    <?php } 
	    if(!empty($linkedin) ) { ?> 
	            <a href="<?php echo esc_url($linkedin); ?>" title="<?php esc_attr_e('LinkedIn','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-linkedin-icon"><i class="fa fa-linkedin"></i></a>
	    <?php } 
	    if(!empty($youtube)) { ?>       
	            <a href="<?php echo esc_url($youtube); ?>" title="<?php esc_attr_e('YouTube','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-youtube-icon"><i class="fa fa-youtube"></i></a>             
	    <?php } 
	    if(!empty($instagram) ) { ?>        
	            <a href="<?php echo esc_url($instagram); ?>" title="<?php esc_attr_e('Instagram','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-instagram-icon"><i class="fa fa-instagram"></i></a>             
	    <?php } 
	    if(!empty($behance) ) { ?>      
	            <a href="<?php echo esc_url($behance); ?>" title="<?php esc_attr_e('Behance','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-behance-icon"><i class="fa fa-behance"></i></a>             
	    <?php } 
	    if(!empty($dribbble) ) { ?>     
	            <a href="<?php echo esc_url($dribbble); ?>" title="<?php esc_attr_e('Dribbble','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-dribbble-icon"><i class="fa fa-dribbble"></i></a>             
	    <?php }
	    if(!empty($pinterest) ) { ?>      
                <a href="<?php echo esc_url($pinterest); ?>" title="<?php esc_attr_e('Pinterest','oviyan-lite'); ?>" target="_blank" class="oviyan-lite-social-network-icon oviyan-lite-pinterest-icon"><i class="fa fa-pinterest"></i></a>             
	    <?php } 

}

/**
 * Social icon header
 *
 * @package oviyan_lite
 * @since 1.0
 */

function oviyan_lite_get_footer_social_icon() {

		$facebook 		= oviyan_lite_get_theme_mod( 'facebook' ); 
		$twitter 		= oviyan_lite_get_theme_mod( 'twitter' );
		$linkedin 		= oviyan_lite_get_theme_mod( 'linkedin' );
		$behance 		= oviyan_lite_get_theme_mod( 'behance' );   
		$dribbble 		= oviyan_lite_get_theme_mod( 'dribbble' );
		$instagram 		= oviyan_lite_get_theme_mod( 'instagram' );
		$youtube 		= oviyan_lite_get_theme_mod( 'youtube' );
		$pinterest      = oviyan_lite_get_theme_mod( 'pinterest' );
		$show_search 	= oviyan_lite_get_theme_mod( 'show_search' );

     	if(!empty($facebook) ) { ?>	
       		<a href="<?php echo esc_url($facebook); ?>" title="<?php esc_attr_e('Facebook','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-facebook-icon"><i class="fa fa-facebook"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'Facebook', 'oviyan-lite' ); ?></span></a>
		<?php } 
		if(!empty($twitter) ) { ?>	
			<a href="<?php echo esc_url($twitter); ?>" title="<?php esc_attr_e('Twitter','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-twitter-icon"><i class="fa fa-twitter"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'Twitter', 'oviyan-lite' ); ?></span></a>
		<?php } 
		if(!empty($linkedin) ) { ?>	
			<a href="<?php echo esc_url($linkedin); ?>" title="<?php esc_attr_e('LinkedIn','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-linkedin-icon"><i class="fa fa-linkedin"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'LinkedIn', 'oviyan-lite' ); ?></span></a>
		<?php } 
		if(!empty($youtube)) { ?>		
			<a href="<?php echo esc_url($youtube); ?>" title="<?php esc_attr_e('YouTube','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-youtube-icon"><i class="fa fa-youtube"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'YouTube', 'oviyan-lite' ); ?></span></a>				
		<?php } 
		if(!empty($instagram) ) { ?>		
			<a href="<?php echo esc_url($instagram); ?>" title="<?php esc_attr_e('Instagram','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-instagram-icon"><i class="fa fa-instagram"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'Instagram', 'oviyan-lite' ); ?></span></a>				
		<?php } 
		if(!empty($behance) ) { ?>		
			<a href="<?php echo esc_url($behance); ?>" title="<?php esc_attr_e('Behance','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-behance-icon"><i class="fa fa-behance"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'Behance', 'oviyan-lite' ); ?></span></a>				
		<?php } 

		if(!empty($dribbble) ) { ?>		
			<a href="<?php echo esc_url($dribbble); ?>" title="<?php esc_attr_e('Dribbble','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-dribbble-icon"><i class="fa fa-dribbble"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'Dribbble', 'oviyan-lite' ); ?></span></a>				
		<?php } 

		if(!empty($pinterest) ) { ?>		
			<a href="<?php echo esc_url($pinterest); ?>" title="<?php esc_attr_e('Pinterest','oviyan-lite'); ?>" target="_blank" class="wpiclt-social-network-icon wpiclt-pinterest-icon"><i class="fa fa-pinterest"></i> <span class="wpiclt-social-text"><?php esc_html_e( 'Pinterest', 'oviyan-lite' ); ?></span></a>				
		<?php }

}
