<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Oviyan
 */

/**
 * Auto add more links.
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_content_more() {	
	/* translators: link read more. */
	$text = wp_kses_post( sprintf( esc_html__( 'Continue reading &#10142; %s', 'oviyan-lite' ), '<span class="screen-reader-text">' . get_the_title() . '</span>' ) );
	$more = sprintf( '<div class="link-more"><a href="%s#more-%d" class="more-link">%s</a></div>', esc_url( get_permalink() ), get_the_ID(), $text );

	if ( !is_admin() ) {
		return $more;
	}
}
add_filter( 'the_content_more_link', 'oviyan_lite_content_more' );

/**
 * Auto add more links.
 * 
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_excerpt_more_link( $excerpt ) {
	
	if ( is_admin() ) {
		return $excerpt;
	}

	if ( is_home() || is_front_page() ) { 	
		$show_readmore 	= oviyan_lite_get_theme_mod( 'blog_show_readmore' );
	} elseif( is_category() || is_archive() ) {
		$show_readmore 	= oviyan_lite_get_theme_mod( 'cat_show_readmore' );
	}else{
		$show_readmore 	= oviyan_lite_get_theme_mod( 'blog_show_readmore' );
	}
	
	if( !empty($show_readmore) ){
		$excerpt 	.= oviyan_lite_content_more();	
	}
    
    return $excerpt;
}
add_filter( 'the_excerpt', 'oviyan_lite_excerpt_more_link', 21 );

/**
 * Change the archive title for category page.
 *
 * @package Oviyan
 * @since 1.0
 */
function oviyan_lite_category_title( $title ) {
	
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	}

	return $title;
}
add_filter( 'get_the_archive_title', 'oviyan_lite_category_title' );

/**
 * Prints HTML with meta information for the current post-date/time and categories, tags..
 */
function oviyan_lite_above_title_posted_on( $meta = array() ) {

     $default_meta = array(                                  
                                    'category' 	=> 1,
                          );

	if( !empty($meta) && is_array($meta) ) {
		foreach ($default_meta as $meta_key => $meta_val) {
			$val = in_array($meta_key, $meta) ? 1 : 0;
			$result_meta[$meta_key] = $val;
		}
	}

	$result_meta = !empty($result_meta) ? $result_meta : $default_meta;
	extract( $result_meta, EXTR_SKIP );

	if( is_home() || is_front_page() || is_search()) {
		$category 	= oviyan_lite_get_theme_mod( 'blog_show_cat' );
	} elseif( is_category() || is_archive() || is_tag() || is_author() ) {
		$category 	= oviyan_lite_get_theme_mod( 'cat_show_cat' );
	}

	// Post Category
	if( $category ) {
		/* translators: used between list items, there is a space after the comma */
		echo '<div class="entry-meta entry-meta-category">';		
		
		$category_name = get_the_category(); 
		
		if(empty($category_name))
		{
		 return;	
		}	

		// use this to echo the slug
		$category_slug = $category_name[0]->slug;

		// use this to echo the cat id
		$category_id = $category_name[0]->cat_ID;
		
		
		// if you've got multiple categories you can run a foreach loop like so
		foreach ( $category_name as $cat ) :				

		$category_link = get_category_link( $cat->cat_ID );
			echo '<a class="cat-link" href="'.esc_url($category_link).'" >' . esc_html($cat->name) . '</a>';

		endforeach;		
		echo '</div>';
	}
		
}




/**
 * Prints HTML with meta information for the current post-date/time and categories, tags..
 */
function oviyan_lite_posted_on( $meta = array() ) {

        $default_meta = array(
                                    'post_date' => 1,
                                    'author' 	=> 1,
                             );

	if( !empty($meta) && is_array($meta) ) {
		foreach ($default_meta as $meta_key => $meta_val) {
			$val = in_array($meta_key, $meta) ? 1 : 0;

			$result_meta[$meta_key] = $val;
		}
	}

	$result_meta = !empty($result_meta) ? $result_meta : $default_meta;
	extract( $result_meta, EXTR_SKIP );

	if( is_home() || is_front_page() || is_search()) {

		$post_date 	= oviyan_lite_get_theme_mod( 'blog_show_date' );
		$author 	= oviyan_lite_get_theme_mod( 'blog_show_author' );
		

	} elseif( is_category() || is_archive() || is_tag() || is_author() ) {

		$post_date 	= oviyan_lite_get_theme_mod( 'cat_show_date' );
		$author 	= oviyan_lite_get_theme_mod( 'cat_show_author' );

	}

	if( $post_date ||  $author  ){
		echo '<div class="entry-meta">';
	}

	// Post Date
	if( $post_date ) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

		echo '<span class="posted-on"><i class="fa fa-clock-o"></i>' . $posted_on . '</span>'; // WPCS: XSS OK.
	}

	// Post Author	
	
	if( $author ) {               
        echo '<span class="byline"><i class="fa fa-user"></i><span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html(get_the_author()) . '</a></span></span>';
	}

	if( $post_date || $author  ) {
		echo '</div>';
	}
}


/**
 * Prints HTML with meta information bellow the Continue reading button
 */
function oviyan_lite_bellow_posted_on( $meta = array() ) {

	 $default_meta = array(
                                    'tag'		=> 1,
                                    'comment'	=> 1,
                          );

	if( !empty($meta) && is_array($meta) ) {
		foreach ($default_meta as $meta_key => $meta_val) {
			$val = in_array($meta_key, $meta) ? 1 : 0;

			$result_meta[$meta_key] = $val;
		}
	}

	$result_meta = !empty($result_meta) ? $result_meta : $default_meta;
	extract( $result_meta, EXTR_SKIP );

	if( is_home() || is_front_page() || is_search()) {

		$tag 				= oviyan_lite_get_theme_mod( 'blog_show_tags' );
		$blog_show_comment 	= oviyan_lite_get_theme_mod( 'blog_show_comment' );

	} elseif( is_category() || is_archive() || is_tag() || is_author() ) {

		$tag 				= oviyan_lite_get_theme_mod( 'cat_show_tags' );
		$blog_show_comment 	= oviyan_lite_get_theme_mod( 'cat_show_comment' );

	}

	$tags_list = get_the_tag_list( '', esc_html__( ', ', 'oviyan-lite' ) );

	if(  ( !empty($tag) && !empty($tags_list) && 'post' === get_post_type() ) || ( !empty($blog_show_comment) &&  !post_password_required() && ( comments_open() || get_comments_number() )) ){

		echo '<div class="entry-meta entry-meta-footer">';
	}

	if ( !empty($blog_show_comment) &&  !post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link"><i class="fa fa-comments-o"></i>';
		/* translators: %s: post title */
		comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'oviyan-lite' ), array(
			'span' => array(
				'class' => array(),
			),
		) ), get_the_title() ) );
		echo '</span>';
	}

	// Hide category and tag text for pages.
	if ( !empty($tag) && !empty($tags_list) &&  'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		echo '<span class="tags-links"><i class="fa fa-tags"></i>' . $tags_list . '</span>'; // WPCS: XSS OK.
	}

	if( ( !empty($tag) && 'post' === get_post_type() && !empty($tags_list) ) || ( !empty($blog_show_comment) &&  !post_password_required() && ( comments_open() || get_comments_number() ) ) ){
		echo '</div>';
	}

}

/**
 * Prints HTML with meta information for the current post-date/time.
 */
function oviyan_lite_featured_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	); 
	echo '<span class="posted-on"><i class="fa fa-clock-o"></i>' . $time_string . '</span>';
}

/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function oviyan_lite_entry_footer() {
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'oviyan-lite' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}

/**
 * Change the tag could args
 *
 * @param array $args Widget parameters.
 *
 * @return mixed
 */
function oviyan_lite_tag_cloud_args( $args ) {
	$args['largest']  = 1; // Largest tag.
	$args['smallest'] = 1; // Smallest tag.
	$args['unit']     = 'em'; // Tag font unit.

	return $args;
}
add_filter( 'widget_tag_cloud_args', 'oviyan_lite_tag_cloud_args' );