<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Oviyan
 * @since 1.0
 */



if ( is_home() || is_front_page() ) { 
	$blog_layout            = oviyan_lite_get_theme_mod( 'blog_layout' );    
} elseif( is_category() || is_archive() ) {
	$blog_layout            = oviyan_lite_get_theme_mod( 'cat_layout' );
        
}

if( $blog_layout == 'grid' ) {
	$main_class = "oviyan-lite-post-grid-main";
} else if ( $blog_layout == 'masonry' ) {
	$main_class = "oviyan-lite-post-grid-main oviyan-lite-post-masonry-wrap";
} else if ($blog_layout == 'list') {
	$main_class = "oviyan-lite-list-main";
} else if ($blog_layout == 'list-alt') {
	$main_class = "oviyan-lite-list-alt-main";
}

get_header(); ?>
<div class="content-row">
	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">
			
			<?php
			if ( have_posts() ) :				
				if ( is_home() && ! is_front_page() ) : ?>
					<header>
						<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
					</header>
			<?php
				endif;                  
               ?>
                 <div class="post-loop-wrap clearfix  <?php echo esc_attr($main_class); ?>" id="post-loop-wrap">
				<?php
				$i = 1;

				$post_count = $wp_query->post_count;
				$count      = 0; 
				/* Start the Loop */
				while ( have_posts() ) : the_post();
					$count++;
					/*
					 * Include the Post-Format-specific template for the content.
					 * If you want to override this in a child theme, then include a file
					 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
					 */
					get_template_part( 'template-parts/content', get_post_format() );
				
				endwhile; ?>
                                </div>
				<?php
				the_posts_pagination( array(
					'prev_text' => esc_html__( '&larr; Previous', 'oviyan-lite' ),
					'next_text' => esc_html__( 'Next &rarr;', 'oviyan-lite' ),
				) );

			else :

				get_template_part( 'template-parts/content', 'none' );

			endif; ?>

		</main><!-- #main -->
	</div><!-- #primary -->

<?php get_sidebar(); ?>
</div> <!-- Content-row -->
<?php
get_footer();